==> noprob-5.x-3.3.tar.gz: noprob/page.tpl.php <==
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" lang="<?php print $language ?>" xml:lang="<?php print $language ?>">
<head>
  <title><?php print $head_title ?></title>
  <?php print $head ?>
  <?php print $styles ?>
  <?php print $scripts ?>
  <style type="text/css" media="print">@import "<?php print base_path() . path_to_theme() ?>/print.css";</style>
  <script type="text/javascript"><?php /* Needed to avoid Flash of Unstyled Content in IE */ ?></script>
</head>

<body>
<div id="wrapper">

<div id="banner" class="clear-block">
  <?php print $search_box ?>
  <?php if ($logo) { ?>
    <a href="<?php print $base_path ?>" title="<?php print t('Home') ?>"><img src="<?php print $logo ?>" alt="<?php print t('Home') ?>" id="logo" /></a>
  <?php } ?>
  <?php if ($site_name) { ?>
    <h1 class="site-name"><a href="<?php print $base_path ?>" title="<?php print t('Home') ?>"><?php print $site_name ?></a></h1>
  <?php } ?>
  <?php if ($site_slogan) { ?>
    <div class="site-slogan"><?php print $site_slogan ?></div>
  <?php } ?>
</div>

<div id="menu">
  <?php if (isset($primary_links)) { ?>
    <?php print theme('links', $primary_links, array('class' =>'links', 'id' => 'primary-links')) ?>
  <?php } ?>
  <?php if (isset($secondary_links)) { ?>
    <?php print theme('links', $secondary_links, array('class' =>'links', 'id' => 'secondary-links')) ?> 
  <?php } ?>
</div>

<?php if ($header) { ?>
  <div id="header"><?php print $header ?></div>
<?php } ?>

<table id="middle" border="0" cellpadding="0" cellspacing="0">
<tr>
  <?php if ($sidebar_left) { ?>
    <td id="sidebar-left" class="sidebar"><?php print $sidebar_left ?></td>
  <?php } ?>
  
  <td id="main" class="content-<?php print $layout ?>">
    <?php print $breadcrumb ?>
    <?php if ($title) { ?>
      <h2 class="title"><?php print $title ?></h2>
    <?php } ?>
    <?php if ($tabs) { ?>
      <div class="tabs"><?php print $tabs ?></div>
    <?php } ?>
    <?php if ($mission) { ?>
      <div id="mission"><?php print $mission ?></div>
    <?php } ?>
<!-- START main content -->
    <?php if ($messages) { print $messages; } ?>
    <?php print $help ?>
    <?php print $content ?>
<!-- END main content -->
    <?php print $feed_icons ?>
  </td>
  
  <?php if ($sidebar_right) { ?>
    <td id="sidebar-right" class="sidebar"><?php print $sidebar_right ?></td>
  <?php } ?>
</tr>
</table>

<?php if ($footer_message) { ?>
  <div id="footer"><?php print $footer_message ?></div>
<?php } ?>

</div>
<?php print $closure ?>
</body>
</html>

==> noprob-5.x-4.1.tar.gz: noprob/page.tpl.php <==
<?php
// $Id: page.tpl.php,v 1.3.6.5.2.3 2008/12/28 02:47:50 eric3 Exp $

/**
 * @file
 * NoProb main template file.
 */
?>

<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" lang="<?php print $language ?>" xml:lang="<?php print $language ?>">
<head>
  <title><?php print $head_title ?></title>
  <?php print $head ?>
  <?php print $styles ?>
  <?php print $scripts ?>
  <style type="text/css" media="print">@import "<?php print base_path() . path_to_theme() ?>/print.css";</style>
  <script type="text/javascript"><?php /* Needed to avoid Flash of Unstyled Content in IE */ ?></script>
</head>
<?php flush(); ?>

<body>
<div id="wrapper">

<div id="banner" class="clear-block">
  <?php print $search_box ?>
  <?php if ($logo) { ?>
    <a href="<?php print $base_path ?>" title="<?php print t('Home') ?>">
      <img src="<?php print $logo ?>" alt="<?php print t('Home') ?>" class="logo" />
    </a>
  <?php } ?>
  <?php if ($site_name) { ?>
    <h1 class="site-name"><a href="<?php print $base_path ?>" title="<?php print t('Home') ?>"><?php print $site_name ?></a></h1>
  <?php } ?>
  <?php if ($site_slogan) { ?>
    <div class="site-slogan"><?php print $site_slogan ?></div>
  <?php } ?>
</div>

<div id="menu">
  <?php if (isset($primary_links)) { ?>
    <?php print theme('links', $primary_links, array('class' => 'links', 'id' => 'primary-links')) ?>
  <?php } ?>
  <?php if (noprob_menu_links('Tertiary links')) { ?>
    <?php print theme('links', menu_primary_links(1, noprob_menu_links('Tertiary links')), array('class' => 'links', 'id' => 'tertiary-links')) ?>
  <?php } ?>
</div>

<?php if ($header) { ?>
  <div id="header"><?php print $header ?></div>
<?php } ?>

<table id="middle" border="0" cellpadding="0" cellspacing="0">
<tr>
  <?php if ($sidebar_left) { ?>
    <td id="sidebar-left" class="sidebar"><?php print $sidebar_left ?></td>
  <?php } ?>

  <td id="main" class="content-<?php print $layout ?>">
    <?php print $breadcrumb ?>
    <?php if ($title) { ?>
      <h2 class="title"><?php print $title ?></h2>
    <?php } ?>
    <?php if ($tabs) { ?>
      <div class="tabs"><?php print $tabs ?></div>
    <?php } ?>
    <?php if ($mission) { ?>
      <div id="mission"><?php print $mission ?></div>
    <?php } ?>
<!-- START main content -->
    <?php if ($messages) print $messages; ?>
    <?php print $help ?>
    <?php print $content ?>
<!-- END main content -->
    <?php print $feed_icons ?>
  </td>

  <?php if ($sidebar_right) { ?>
    <td id="sidebar-right" class="sidebar"><?php print $sidebar_right ?></td>
  <?php } ?>
</tr>
</table>

<div id="footer">
  <?php if ($secondary_links || $footer_message) { ?>
    <?php print theme('links', $secondary_links, array('class' => 'links', 'id' => 'secondary-links')) . $footer_message ?>
  <?php } ?>
</div>

</div>
<?php print $closure ?>
</body>
</html>
